@@ -19,7 +19,7 @@ calculateFeatureSet = function(feat.object, set, control, ...) {
     ela_meta = calculateMetaModelFeatures(feat.object),
     basic = calculateBasicFeatures(feat.object),
     disp = calculateDispersionFeatures(feat.object, control),
-    limo = calculateLinearModelFeatures(feat.object),
+    limo = calculateLinearModelFeatures(feat.object, control),
     nbc = calculateNearestBetterFeatures(feat.object, control),
     pca = calculatePrincipalComponentFeatures(feat.object, control),
     bt = calculateBarrierTreeFeatures(feat.object, control),
