@@ -77,3 +77,19 @@ test_that("Dealing with plateaus", {
   expect_equal(features$bt.near.diffs.max, max(ydiffs))
   expect_equal(features$bt.near.diffs.sd, sd(ydiffs))
 })
+
+test_that("Show Error", {
+  set.seed(2015*03*26)
+
+  # (1) create a feature object:
+  X = expand.grid(1:4, 1:3)
+  y = c(1, 1, 3, 2, 1, 1, 4, 2.5, 1.5, 2.5, 3.5, 0)
+  feat.object = createFeatureObject(X = X, y = y, blocks = c(4, 3),
+    lower = c(0.5, 0.5), upper = c(4.5, 3.5))
+
+  expect_error(calculateFeatureSet(feat.object, "bt",
+    control = list(allow_cellmapping = FALSE)))
+  feat.object = createFeatureObject(X = X, y = y,
+    lower = c(0.5, 0.5), upper = c(4.5, 3.5))
+  expect_error(calculateFeatureSet(feat.object, "bt"))
+})
